API Documentation
=================


Model classes
-------------

.. automodule:: tsplib95.models
    :members:
    :undoc-members:
    :show-inheritance:

Matrix weights
--------------

.. automodule:: tsplib95.matrix
    :members:
    :undoc-members:
    :show-inheritance:

Distance functions
------------------

.. automodule:: tsplib95.distances
    :members:
    :undoc-members:
    :show-inheritance:

Utilities
---------

.. automodule:: tsplib95.utils
    :members:
